summaryrefslogtreecommitdiff
path: root/src/view_2d.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/view_2d.hpp')
-rw-r--r--src/view_2d.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/view_2d.hpp b/src/view_2d.hpp
index f2ff5b6..a18937e 100644
--- a/src/view_2d.hpp
+++ b/src/view_2d.hpp
@@ -1,5 +1,5 @@
/*
- * Copyright 2022-2023 Frederico de Oliveira Linhares
+ * Copyright 2022-2024 Frederico de Oliveira Linhares
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -23,8 +23,8 @@ extern const struct mrb_data_type cg_view_2d_type;
// Receives a mrb_value that points to a View2D or a View3D and returns a
// pointer to View2D. If the mrb_value points to a View3D, the view will be
-// cast to a VK::View2D.
-VK::View2D*
+// cast to a BluCat::View2D.
+BluCat::View2D*
cg_cView_to_view_2d(mrb_state *mrb, mrb_value view_value);
void